==> nextcloud-app-mail-1.5.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ar.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "فشل في عملية التحقق الآلي. الرجاء استخدام نمط الدليل.",
    "Updating account failed: " : "فشلت عملية تحديث الحساب :",
    "Creating account failed: " : "فشل في إنشاء الحساب:",
    "Mails" : "الرسائل",
    "Mail" : "البريد",
    "Name" : "الإسم",
    "Mail Address" : "عنوان البريد الإلكتروني",
    "Password" : "كلمة المرور",
    "Manual" : "يدوي",
    "IMAP Settings" : "إعدادات IMAP",
    "IMAP Host" : "مُضيف IMAP",
    "None" : "بلا",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "منفذ IMAP",
    "IMAP User" : "مستخدم IMAP",
    "IMAP Password" : "كلمة مرور IMAP",
    "SMTP Settings" : "إعدادات SMTP",
    "SMTP Host" : "مُضيف SMTP",
    "SMTP Port" : "منفذ SMTP",
    "SMTP User" : "مستخدم SMTP",
    "SMTP Password" : "كلمة مرور SMTP",
    "Save" : "حفظ",
    "Connect" : "اتصال",
    "Add mail account" : "أضف حساب بريدي",
    "Select account" : "إختيار حساب",
    "Subject" : "الموضوع",
    "Upload attachment" : "رفع المرفقات",
    "Add attachment from Files" : "إضافة مرفقات مِن الملفات",
    "Sending …" : "جار الإرسال",
    "Go back" : "العودة",
    "Retry" : "أعد المحاولة",
    "Message sent!" : "تم الإرسال الرسالة!",
    "Send" : "أرسل",
    "Choose a file to add as attachment" : "اختر ملف لإضافته كمرفق",
    "Choose a file to share as a link" : "اختر ملفا لمشاركته كرابط",
    "Draft: " : "المسودة:",
    "Unselect" : "إلغاء التحديد",
    "Select" : "تحديد",
    "Delete" : "حذف",
    "Important" : "مهم",
    "Favorites" : "المفضلات",
    "Other" : "آخر",
    "Attachments" : "المرفقات",
    "Import into calendar" : "إستيراد من التقويم",
    "Download attachment" : "تنزيل الملحق",
    "Save to Files" : "حفظ للـ الملفات",
    "Choose a folder to store the attachment in" : "اختر مجلد لتخزين المرفقات ",
    "Save all to Files" : "حفظ الجميع لـ الملفات",
    "The images have been blocked to protect your privacy." : "تم حجب هذه الصورة لحماية خصوصيتك",
    "Show images from this sender" : "أظهر الصور من هذا المُرسل",
    "New message" : "رسالة جديدة",
    "Settings" : "الإعدادات",
    "Quota" : "الحصة",
    "Add folder" : "إضافة مجلد",
    "Saving" : "جاري الحفظ ...",
    "Remove account" : "حذف حساب",
    "Cancel" : "إلغاء",
    "Show all folders" : "أظهر جميع المجلدات",
    "Collapse folders" : "طي المجلدات",
    "Mark all as read" : "تحديد الكل كمقروء",
    "Clear cache" : "مسح ذاكرة التخزين المؤقتة",
    "Delete folder" : "حذف المجلد",
    "Not found" : "غير موجود",
    "Signature" : "التوقيع",
    "Reply" : "رد",
    "Forward" : "إعادة توجيه ",
    "General" : "العامة",
    "Email address" : "عنوان البريد الإلكتروني",
    "User" : "المستخدم",
    "Host" : "المضيف",
    "Port" : "المنفذ",
    "Mail server" : "خادم البريد",
    "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
    "Speed up your Mail experience with these quick shortcuts." : "سرّع تجربة بريدك مع هذه الإختصارات.",
    "Compose new message" : "إرسل رسالة جديدة",
    "Newer message" : "الرسائل الأحدث",
    "Older message" : "الرسائل الأقدم",
    "Toggle star" : "حدد النجوم",
    "Toggle unread" : "حدد الغير مقروء",
    "Search" : "بحث",
    "Refresh" : "تحديث",
    "Connect your mail account" : "تحديث",
    "All" : "الكل",
    "Archive" : "الأرشيف",
    "Drafts" : "المسودات",
    "All inboxes" : "جميع الوارد",
    "Inbox" : "صندوق الوارد",
    "Junk" : "عشوائي",
    "Sent" : "أرسلت",
    "Trash" : "سلة المحذوفات",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "بريد ناكست كلاود",
    "Could not load {tag}{name}{endtag}" : "تعذر تحميل {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "حدث خطأ ما عند تحميل {tag}{name}{endtag}",
    "Could not load your message" : "تعذرت عملية تحميل رسالتك",
    "Could not load the message" : "تعذرت عملية تحميل الرسالة",
    "Error loading message" : "حدث خطأ خلال تحميل الرسالة",
    "Forwarding to %s" : "تمرير إلى %s",
    "Click here if you are not automatically redirected within the next few seconds." : "إضغط هنا إذا لم يتم إعادة توجيهك تلقائياً بعد عدة ثواني.",
    "Redirect" : "إعادة توجيه",
    "The link leads to %s" : "الرابط يؤدي إل %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "إذا لم ترغب في زيارة الصفحة، بإمكانك العودة لـ <a href=\"%s\">البريد</a>",
    "Continue to %s" : "أكمل إلى %s"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-app-mail-1.7.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ar.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "فشل في عملية التحقق الآلي. الرجاء استخدام نمط الدليل.",
    "Updating account failed: " : "فشلت عملية تحديث الحساب :",
    "Creating account failed: " : "فشل في إنشاء الحساب:",
    "Mails" : "الرسائل",
    "Mail" : "البريد",
    "Defaults" : "الافتراضي",
    "Here you can select where Nextcloud Mail stores your drafts as well as sent and deleted messages." : "من هنا تستطيع تحديد مكان تخزين المسودات في Nextcloud Mail وايضا المرسلات والرسائل المحذوفه.",
    "Draft messages are saved to:" : "المسودات سيتم حفظها في:",
    "Sent messages are saved to:" : "الرسائل المرسلة يتم تخزينها في:",
    "Deleted messages are moved to:" : "الرسائل المحذوفه سيتم نقلها إلى:",
    "Name" : "الإسم",
    "Mail Address" : "عنوان البريد الإلكتروني",
    "Password" : "كلمة المرور",
    "Manual" : "يدوي",
    "IMAP Settings" : "إعدادات IMAP",
    "IMAP Host" : "مُضيف IMAP",
    "None" : "بلا",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "منفذ IMAP",
    "IMAP User" : "مستخدم IMAP",
    "IMAP Password" : "كلمة مرور IMAP",
    "SMTP Settings" : "إعدادات SMTP",
    "SMTP Host" : "مُضيف SMTP",
    "SMTP Port" : "منفذ SMTP",
    "SMTP User" : "مستخدم SMTP",
    "SMTP Password" : "كلمة مرور SMTP",
    "Save" : "حفظ",
    "Connect" : "اتصال",
    "Add mail account" : "أضف حساب بريدي",
    "Select account" : "إختيار حساب",
    "Subject" : "الموضوع",
    "Can not save draft because this account does not have a drafts mailbox configured." : "لا يمكن حفظ المسودة وذلك بسبب عدم ضبط اعدادات المسودات صندوق البريد في هذا الحساب.",
    "Upload attachment" : "رفع المرفقات",
    "Add attachment from Files" : "إضافة مرفقات مِن الملفات",
    "Sending …" : "جار الإرسال",
    "Go back" : "العودة",
    "Retry" : "أعد المحاولة",
    "Message sent!" : "تم الإرسال الرسالة!",
    "Send" : "أرسل",
    "No sent mailbox configured. Please pick one in the account settings." : "لم يتم اعداد الرسائل في المرسلة في صندوق البريد. يرجى اختيار واحد في اعدادات الحساب.",
    "Choose a file to add as attachment" : "اختر ملف لإضافته كمرفق",
    "Choose a file to share as a link" : "اختر ملفا لمشاركته كرابط",
    "Draft: " : "المسودة:",
    "Unselect" : "إلغاء التحديد",
    "Select" : "تحديد",
    "Move" : "نقل",
    "Edit as new message" : "تحرير كرسالة جديدة",
    "Delete" : "حذف",
    "No trash mailbox configured" : "لم يتم اعداد سلة المحذوفات لصندوق البريد",
    "Could not delete message" : "لا يمكن حذف الرسالة",
    "No more subfolders in here" : "لا يوجد هنا ملفات فرعية",
    "Choose" : "إختر",
    "Important" : "مهم",
    "Favorites" : "المفضلات",
    "Other" : "آخر",
    "Attachments" : "المرفقات",
    "Import into calendar" : "إستيراد من التقويم",
    "Download attachment" : "تنزيل الملحق",
    "Save to Files" : "حفظ للـ الملفات",
    "Choose a folder to store the attachment in" : "اختر مجلد لتخزين المرفقات ",
    "Save all to Files" : "حفظ الجميع لـ الملفات",
    "The images have been blocked to protect your privacy." : "تم حجب هذه الصورة لحماية خصوصيتك",
    "Show images from this sender" : "أظهر الصور من هذا المُرسل",
    "New message" : "رسالة جديدة",
    "Settings" : "الإعدادات",
    "Quota" : "الحصة",
    "Show only subscribed folders" : "عرض المجدات المشتركه بها فقط.",
    "Add folder" : "إضافة مجلد",
    "Saving" : "جاري الحفظ ...",
    "Remove account" : "حذف حساب",
    "Cancel" : "إلغاء",
    "Show all subscribed folders" : "عرض جميع اشتراك المجلدات.",
    "Show all folders" : "أظهر جميع المجلدات",
    "Collapse folders" : "طي المجلدات",
    "Mark all as read" : "تحديد الكل كمقروء",
    "Clear cache" : "مسح ذاكرة التخزين المؤقتة",
    "Delete folder" : "حذف المجلد",
    "Not found" : "غير موجود",
    "Attachments were not copied. Please add them manually." : "المرفقات لم يتم نسخها. يرجى اضافتها يدويا.",
    "Signature" : "التوقيع",
    "Reply" : "رد",
    "Forward" : "إعادة توجيه ",
    "General" : "العامة",
    "Email address" : "عنوان البريد الإلكتروني",
    "User" : "المستخدم",
    "Host" : "المضيف",
    "Port" : "المنفذ",
    "Mail server" : "خادم البريد",
    "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
    "Speed up your Mail experience with these quick shortcuts." : "سرّع تجربة بريدك مع هذه الإختصارات.",
    "Compose new message" : "إرسل رسالة جديدة",
    "Newer message" : "الرسائل الأحدث",
    "Older message" : "الرسائل الأقدم",
    "Toggle star" : "حدد النجوم",
    "Toggle unread" : "حدد الغير مقروء",
    "Search" : "بحث",
    "Refresh" : "تحديث",
    "Connect your mail account" : "تحديث",
    "All" : "الكل",
    "Archive" : "الأرشيف",
    "Drafts" : "المسودات",
    "All inboxes" : "جميع الوارد",
    "Inbox" : "صندوق الوارد",
    "Junk" : "عشوائي",
    "Sent" : "أرسلت",
    "Trash" : "سلة المحذوفات",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "بريد ناكست كلاود",
    "Could not load {tag}{name}{endtag}" : "تعذر تحميل {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "حدث خطأ ما عند تحميل {tag}{name}{endtag}",
    "Could not load your message" : "تعذرت عملية تحميل رسالتك",
    "Could not load the message" : "تعذرت عملية تحميل الرسالة",
    "Error loading message" : "حدث خطأ خلال تحميل الرسالة",
    "Forwarding to %s" : "تمرير إلى %s",
    "Click here if you are not automatically redirected within the next few seconds." : "إضغط هنا إذا لم يتم إعادة توجيهك تلقائياً بعد عدة ثواني.",
    "Redirect" : "إعادة توجيه",
    "The link leads to %s" : "الرابط يؤدي إل %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "إذا لم ترغب في زيارة الصفحة، بإمكانك العودة لـ <a href=\"%s\">البريد</a>",
    "Continue to %s" : "أكمل إلى %s"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
